@@ -128,7 +128,7 @@ cat_mip_rule_ <- function(e, name, ...){
   a <- unlist(lapply(rule_l, function(x){
     vars <- bin_var_name(x)
     # if (x %in% set) +1, if (!(x %in% set)) -1
-    coef <- rep(if(x$not) -1L else 1L, length(vars))
+    coef <- rep(if(x$not || all(x$value == FALSE)) -1L else 1L, length(vars))
     names(coef) <- vars
     coef
   })
@@ -137,14 +137,14 @@ cat_mip_rule_ <- function(e, name, ...){
   # sum(a_pos) + sum(1-a_neg) >= 1
   # condition is that at least one of the variable is true, extract the negated memberships
   b <- 1 - sum(sapply(rule_l, function(x){
-    x$not
+    x$not || all(x$value == FALSE)
   }))
 
   if ( length(rule_l) == 1){
-    if (length(a) > 1 || op(e) == "=="){  # this is a strict(er) version and allows for some optimization
+    if (isTRUE(length(a) > 1) || op(e) == "=="){  # this is a strict(er) version and allows for some optimization
       mip_rule(a, "==", b, name, type=sapply(a, function(x) 'binary'))
     } else {
-      mip_rule(a, "<=", b, name, type=sapply(a, function(x) 'binary')) # needed for logical variables
+      mip_rule(-a, "<=", -b, name, type=sapply(a, function(x) 'binary')) # needed for logical variables
     }
   } else {
     mip_rule(-a, "<=", -b, name, type=sapply(a, function(x) 'binary')) # normalized version of a*x >= b
