@@ -16,6 +16,10 @@ describe("is_linear",{
     v <- validator(x > 1, y + 2*x <= 3, A == "a", A == TRUE)
     expect_equal(is_linear(v), c(TRUE, TRUE, FALSE, FALSE))
   })
+  it("can detect negative coefficients",{
+    v <- validator(x > -3*y)
+    expect_true(is_linear(v))
+  })
 })
 
 describe("lin_mip_rule",{
